Agent Stream Kit - A framework for building and managing agents in Rust
This crate provides a set of tools and abstractions to create, configure, and run agents in a stream-based architecture. It includes support for defining agent behaviors, managing agent flows, handling agent input and output.
Re-exports
pub extern crate self as agent_stream_ kit;
Re-exports
pub use inventory;
Structs
- ASKit
- Agent
Config Entry - Agent
Configs - Agent
Context - Agent
Definition - Agent
Display Config Entry - Agent
Flow - Agent
Flow Edge - Agent
Flow Node - Agent
Registration - Registration entry emitted by the
#[askit_agent]macro. - AsAgent
Data