AgentValue

Enum AgentValue 

pub enum AgentValue {
    Unit,
    Boolean(bool),
    Integer(i64),
    Number(f64),
    String(Arc<String>),
    Image(Arc<PhotonImage>),
    Array(Vector<AgentValue>),
    Object(HashMap<String, AgentValue>),
    Tensor(Arc<Vec<f32>>),
    Message(Arc<Message>),
    Error(Arc<AgentError>),
}

Variants



Unit



Boolean(bool)



Integer(i64)



Number(f64)



String(Arc<String>)



Image(Arc<PhotonImage>)



Array(Vector<AgentValue>)



Object(HashMap<String, AgentValue>)



Tensor(Arc<Vec<f32>>)



Message(Arc<Message>)



Error(Arc<AgentError>)

Implementations

Source

impl AgentValue

pub fn unit() -> Self

pub fn boolean(value: bool) -> Self

pub fn integer(value: i64) -> Self

pub fn number(value: f64) -> Self

pub fn string(value: impl Into<String>) -> Self

pub fn image(value: PhotonImage) -> Self

pub fn image_arc(value: Arc<PhotonImage>) -> Self

pub fn array(value: Vector<AgentValue>) -> Self

pub fn object(value: AgentValueMap<String, AgentValue>) -> Self

pub fn tensor(value: Vec<f32>) -> Self

pub fn message(value: Message) -> Self

pub fn boolean_default() -> Self

pub fn integer_default() -> Self

pub fn number_default() -> Self

pub fn string_default() -> Self

pub fn image_default() -> Self

pub fn array_default() -> Self

pub fn object_default() -> Self

pub fn tensor_default() -> Self

pub fn from_json(value: Value) -> Result<Self, AgentError>

pub fn to_json(&self) -> Value

pub fn from_serialize<T: Serialize>(value: &T) -> Result<Self, AgentError>

Create AgentValue from Serialize

pub fn to_deserialize<T: for<'de> Deserialize<'de>>( &self, ) -> Result<T, AgentError>

Convert AgentValue to a Deserialize

pub fn is_unit(&self) -> bool

pub fn is_boolean(&self) -> bool

pub fn is_integer(&self) -> bool

pub fn is_number(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_image(&self) -> bool

pub fn is_array(&self) -> bool

pub fn is_object(&self) -> bool

pub fn is_tensor(&self) -> bool

pub fn is_message(&self) -> bool

pub fn as_bool(&self) -> Option<bool>

pub fn as_i64(&self) -> Option<i64>

pub fn as_f64(&self) -> Option<f64>

pub fn as_str(&self) -> Option<&str>

pub fn as_image(&self) -> Option<&PhotonImage>

pub fn as_image_mut(&mut self) -> Option<&mut PhotonImage>

If self is an Image, get a mutable reference to the inner PhotonImage.

pub fn into_image(self) -> Option<Arc<PhotonImage>>

If self is an Image, extract the inner PhotonImage; otherwise, return None. This consumes self.

pub fn as_message(&self) -> Option<&Message>

pub fn as_message_mut(&mut self) -> Option<&mut Message>

pub fn into_message(self) -> Option<Arc<Message>>

pub fn to_boolean(&self) -> Option<bool>

Convert to Boolean.

pub fn to_boolean_value(&self) -> Option<AgentValue>

Convert to AgentValue::Boolean or AgentValue::Array of booleans.

pub fn to_integer(&self) -> Option<i64>

Convert to Integer (i64).

pub fn to_integer_value(&self) -> Option<AgentValue>

Convert to AgentValue::Integer or AgentValue::Array of integers.

pub fn to_number(&self) -> Option<f64>

Convert to Number (f64).

pub fn to_number_value(&self) -> Option<AgentValue>

Convert to AgentValue::Number or AgentValue::Array of numbers.

pub fn to_string(&self) -> Option<String>

Convert to String.

pub fn to_string_value(&self) -> Option<AgentValue>

Convert to AgentValue::String or AgentValue::Array of strings.

pub fn to_message(&self) -> Option<Message>

Convert to Message.

pub fn to_message_value(&self) -> Option<AgentValue>

Convert to AgentValue::Message or AgentValue::Array of messages. If the value is an array, it recursively converts its elements.

pub fn as_object(&self) -> Option<&AgentValueMap<String, AgentValue>>

pub fn as_object_mut( &mut self, ) -> Option<&mut AgentValueMap<String, AgentValue>>

pub fn into_object(self) -> Option<AgentValueMap<String, AgentValue>>

If self is an Object, extract the inner HashMap; otherwise, return None. This consumes self.

pub fn as_array(&self) -> Option<&Vector<AgentValue>>

pub fn as_array_mut(&mut self) -> Option<&mut Vector<AgentValue>>

pub fn into_array(self) -> Option<Vector<AgentValue>>

If self is an Array, extract the inner Vector; otherwise, return None. This consumes self.

pub fn as_tensor(&self) -> Option<&Vec<f32>>

pub fn as_tensor_mut(&mut self) -> Option<&mut Vec<f32>>

pub fn into_tensor(self) -> Option<Arc<Vec<f32>>>

If self is a Tensor, extract the inner Vec; otherwise, return None. This consumes self.

pub fn into_tensor_vec(self) -> Option<Vec<f32>>

If self is a Tensor, extract the inner Vec; otherwise, return None.

This consumes self. Possibly O(n) copy.

pub fn get(&self, key: &str) -> Option<&AgentValue>

pub fn get_mut(&mut self, key: &str) -> Option<&mut AgentValue>

pub fn get_bool(&self, key: &str) -> Option<bool>

pub fn get_i64(&self, key: &str) -> Option<i64>

pub fn get_f64(&self, key: &str) -> Option<f64>

pub fn get_str(&self, key: &str) -> Option<&str>

pub fn get_image(&self, key: &str) -> Option<&PhotonImage>

pub fn get_image_mut(&mut self, key: &str) -> Option<&mut PhotonImage>

pub fn get_object( &self, key: &str, ) -> Option<&AgentValueMap<String, AgentValue>>

pub fn get_object_mut( &mut self, key: &str, ) -> Option<&mut AgentValueMap<String, AgentValue>>

pub fn get_array(&self, key: &str) -> Option<&Vector<AgentValue>>

pub fn get_array_mut(&mut self, key: &str) -> Option<&mut Vector<AgentValue>>

pub fn get_tensor(&self, key: &str) -> Option<&Vec<f32>>

pub fn get_tensor_mut(&mut self, key: &str) -> Option<&mut Vec<f32>>

pub fn get_message(&self, key: &str) -> Option<&Message>

pub fn get_message_mut(&mut self, key: &str) -> Option<&mut Message>

pub fn set(&mut self, key: String, value: AgentValue) -> Result<(), AgentError>