AgentConfigEntry

Struct AgentConfigEntry 

pub struct AgentConfigEntry {
    pub value: AgentValue,
    pub type_: Option<String>,
    pub title: Option<String>,
    pub description: Option<String>,
    pub hidden: bool,
}

Fields

value: AgentValuetype_: Option<String>title: Option<String>description: Option<String>hidden: bool

Indicates whether this configuration entry should be hidden from the user interface. If set to true, the entry will be hidden. The default behavior is to show the entry.

Implementations

Source

impl AgentConfigEntry

pub fn new<V: Into<AgentValue>>(value: V, type_: &str) -> Self

pub fn with_title(self, title: &str) -> Self

pub fn with_description(self, description: &str) -> Self

pub fn with_hidden(self) -> Self