pub struct AgentConfigSpec {
pub value: AgentValue,
pub type_: Option<String>,
pub title: Option<String>,
pub hide_title: bool,
pub description: Option<String>,
pub hidden: bool,
pub readonly: bool,
}Fields
value: AgentValuetype_: Option<String>title: Option<String>hide_title: booldescription: Option<String>Indicates whether this configuration entry should be hidden from the user interface.
If set to true, the entry will be hidden.
readonly: boolIndicates whether this configuration entry is read-only.
Implementations
Sourceimpl AgentConfigSpec
impl AgentConfigSpec
pub fn new<V: Into<AgentValue>>(value: V, type_: &str) -> Self
pub fn title(self, title: &str) -> Self
pub fn hide_title(self) -> Self
pub fn description(self, description: &str) -> Self
pub fn readonly(self) -> Self