pub struct AgentStream { /* private fields */ }Implementations
Sourceimpl AgentStream
impl AgentStream
Sourcepub fn new(name: String, spec: AgentStreamSpec) -> Self
pub fn new(name: String, spec: AgentStreamSpec) -> Self
Create a new agent stream with the given name and spec.
The ids of the given spec, including agents and channels, are changed to new unique ids.
pub fn id(&self) -> &str
pub fn spec(&self) -> &AgentStreamSpec
pub fn update_spec(&mut self, value: &Value) -> Result<(), AgentError>
pub fn name(&self) -> &str
pub fn set_name(&mut self, name: String)
pub fn add_agent(&mut self, agent: AgentSpec)
pub fn remove_agent(&mut self, agent_id: &str)
pub fn add_channel(&mut self, channel: ChannelSpec)
pub fn remove_channel(&mut self, channel: &ChannelSpec) -> Option<ChannelSpec>
pub fn running(&self) -> bool
pub async fn start(&mut self, askit: &ASKit) -> Result<(), AgentError>
pub async fn stop(&mut self, askit: &ASKit) -> Result<(), AgentError>