pub struct ASKit { /* private fields */ }Implementations
Sourceimpl ASKit
impl ASKit
pub fn new() -> Self
pub fn init() -> Result<Self, AgentError>
pub async fn ready(&self) -> Result<(), AgentError>
pub fn quit(&self)
pub fn register_agent_definiton(&self, def: AgentDefinition)
pub fn get_agent_definitions(&self) -> AgentDefinitions
pub fn get_agent_definition(&self, def_name: &str) -> Option<AgentDefinition>
pub fn get_agent_config_specs(&self, def_name: &str) -> Option<AgentConfigSpecs>
pub fn get_agent_spec(&self, agent_id: &str) -> Option<AgentSpec>
Sourcepub fn get_agent_stream_info(&self, id: &str) -> Option<AgentStreamInfo>
pub fn get_agent_stream_info(&self, id: &str) -> Option<AgentStreamInfo>
Get info of the agent stream by id.
Sourcepub fn get_agent_stream_infos(&self) -> Vec<AgentStreamInfo>
pub fn get_agent_stream_infos(&self) -> Vec<AgentStreamInfo>
Get infos of all agent streams.
Sourcepub fn get_agent_stream_spec(&self, id: &str) -> Option<AgentStreamSpec>
pub fn get_agent_stream_spec(&self, id: &str) -> Option<AgentStreamSpec>
Get the agent stream spec by id.
Sourcepub fn set_agent_stream_spec(
&self,
id: &str,
spec: AgentStreamSpec,
) -> Result<(), AgentError>
pub fn set_agent_stream_spec( &self, id: &str, spec: AgentStreamSpec, ) -> Result<(), AgentError>
Set the agent stream spec by id.
Sourcepub fn new_agent_stream(&self, name: &str) -> Result<String, AgentError>
pub fn new_agent_stream(&self, name: &str) -> Result<String, AgentError>
Create a new agent stream with the given name. If the name already exists, a unique name will be generated by appending a number suffix. Returns the id of the new agent stream.
pub fn rename_agent_stream( &self, id: &str, new_name: &str, ) -> Result<String, AgentError>
pub fn unique_stream_name(&self, name: &str) -> String
pub fn add_agent_stream( &self, name: String, spec: AgentStreamSpec, ) -> Result<String, AgentError>
pub async fn remove_agent_stream(&self, id: &str) -> Result<(), AgentError>
pub fn copy_sub_stream( &self, agents: &Vec<AgentSpec>, channels: &Vec<ChannelSpec>, ) -> (Vec<AgentSpec>, Vec<ChannelSpec>)
pub async fn start_agent_stream(&self, id: &str) -> Result<(), AgentError>
pub async fn stop_agent_stream(&self, id: &str) -> Result<(), AgentError>
Sourcepub fn new_agent_spec(&self, def_name: &str) -> Result<AgentSpec, AgentError>
pub fn new_agent_spec(&self, def_name: &str) -> Result<AgentSpec, AgentError>
Create a new agent spec from the given agent definition name.
Sourcepub fn add_agent(
&self,
stream_id: String,
spec: AgentSpec,
) -> Result<(), AgentError>
pub fn add_agent( &self, stream_id: String, spec: AgentSpec, ) -> Result<(), AgentError>
Add an agent to the specified stream.
Sourcepub fn get_agent(
&self,
agent_id: &str,
) -> Option<Arc<AsyncMutex<Box<dyn Agent>>>>
pub fn get_agent( &self, agent_id: &str, ) -> Option<Arc<AsyncMutex<Box<dyn Agent>>>>
Get the agent by id.
pub fn add_channel( &self, stream_id: &str, channel: ChannelSpec, ) -> Result<(), AgentError>
pub async fn remove_agent( &self, stream_id: &str, agent_id: &str, ) -> Result<(), AgentError>
pub fn remove_channel( &self, stream_id: &str, channel_id: &str, ) -> Result<(), AgentError>
pub async fn start_agent(&self, agent_id: &str) -> Result<(), AgentError>
pub async fn stop_agent(&self, agent_id: &str) -> Result<(), AgentError>
pub async fn set_agent_configs( &self, agent_id: String, configs: AgentConfigs, ) -> Result<(), AgentError>
pub fn get_global_configs(&self, def_name: &str) -> Option<AgentConfigs>
pub fn set_global_configs(&self, def_name: String, configs: AgentConfigs)
pub fn get_global_configs_map(&self) -> AgentConfigsMap
pub fn set_global_configs_map(&self, new_configs_map: AgentConfigsMap)
pub async fn agent_input( &self, agent_id: String, ctx: AgentContext, pin: String, value: AgentValue, ) -> Result<(), AgentError>
pub async fn send_agent_out( &self, agent_id: String, ctx: AgentContext, pin: String, value: AgentValue, ) -> Result<(), AgentError>
pub fn try_send_agent_out( &self, agent_id: String, ctx: AgentContext, pin: String, value: AgentValue, ) -> Result<(), AgentError>
pub fn write_board_value( &self, name: String, value: AgentValue, ) -> Result<(), AgentError>
pub fn write_var_value( &self, stream_id: &str, name: &str, value: AgentValue, ) -> Result<(), AgentError>
pub fn subscribe(&self, observer: Box<dyn ASKitObserver + Sync + Send>) -> usize
pub fn unsubscribe(&self, observer_id: usize)