pub struct AgentConfigEntry {
pub value: AgentValue,
pub type_: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub hidden: bool,
}Fields
value: AgentValuetype_: Option<String>title: Option<String>description: Option<String>Indicates whether this configuration entry should be hidden from the user interface.
If set to true, the entry will be hidden. The default behavior is to show the entry.
Implementations
Sourceimpl AgentConfigEntry
impl AgentConfigEntry
pub fn new(value: AgentValue, type_: &str) -> Self
pub fn with_title(self, title: &str) -> Self
pub fn with_description(self, description: &str) -> Self