Module test_utils

Module test_utils 

Structs

BoardObserver
ProbeReceiver
TestProbeAgent

Constants

DEFAULT_BOARD_TIMEOUT
DEFAULT_PROBE_TIMEOUT

Functions

expect_board_value
expect_var_value
load_and_start_stream
Load and start an agent stream from a file.
probe_receiver
Helper to fetch the probe receiver for a TestProbeAgent by id.
recv_board_with_timeout
recv_probe
Receive one probe event with the default timeout.
recv_probe_with_timeout
Await one probe event with timeout on the given receiver.
setup_askit
Setting up ASKit
subscribe_board_observer

Type Aliases

ProbeEvent