Module test_utils

Module test_utils 

Structs

ProbeReceiver
TestProbeAgent

Constants

DEFAULT_PROBE_TIMEOUT

Functions

probe_receiver
Helper to fetch the probe receiver for a TestProbeAgent by id.
recv_probe
Receive one probe event with the default timeout.
recv_probe_with_timeout
Await one probe event with timeout on the given receiver.

Type Aliases

ProbeEvent